PyEDB-Core documentation |version|
==================================

..
   Simply reuse the root readme

.. include:: ../../README.rst
   :start-after: .. reuse_start

.. toctree::
   :hidden:

   getting_started/index
   user_guide/index
   api/index
   examples/index
   contribute

Indices and tables
==================
* :ref:`genindex`
* :ref:`search`

